/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or http://eu-egee.org/license.html
 *
 * Author Peter Kunszt <peter.kunszt@cern.ch>
 * $Id: TransferLogger.hxx,v 1.6 2005/09/21 11:44:40 pkunszt Exp $
 */

#ifndef GLITE_DATA_TRANSFER_LOGGER_HXX_
#define GLITE_DATA_TRANSFER_LOGGER_HXX_

#include <string>
#include "log4cxx/logger.h"

namespace glite{
namespace transfer{

class TransferLogger {
public:
    typedef enum {
	INFO  = 0,
	WARN = 1,
	ERROR = 2,
	DEBUG = 3
    } Level;

    TransferLogger(const std::string &id);

    ~TransferLogger();

    // copy constructor
    TransferLogger(const TransferLogger &) ;

    // assignment operator
    TransferLogger & operator=(const TransferLogger &);

    void setVerbose();
    void setDebug();
    void setLogfile(const std::string &filename);
    void setLevel(Level level);
    void activateConsole();
    void writeContext(void *);
    void error(const char *msg, const char *msg = NULL);
    void debug(const char *msg, const char *msg = NULL);
    void info(const char *msg, const char *msg = NULL);
    void warn(const char *msg, const char *msg = NULL);

private:
    log4cxx::LoggerPtr m_logger;
    log4cxx::LoggerPtr m_loggersrm;
    bool        m_verbose;
    static log4cxx::LayoutPtr s_layout;
};

} // namespace transfer
} // namespace glite

#endif //GLITE_DATA_TRANSFER_LOGGER_HXX_
