/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or http://eu-egee.org/license.html
 *
 * Author Peter Kunszt <peter.kunszt@cern.ch>
 * $Id: TransferSocket.hxx,v 1.6 2006/03/13 13:51:59 mccance Exp $
 */

#ifndef GLITE_DATA_TRANSFER_SOCKET_HXX_
#define GLITE_DATA_TRANSFER_SOCKET_HXX_

extern "C" {
#include <sys/un.h>
}

#include <string>
#include "glite/data/transfer/TransferFiles.hxx"


namespace glite{
namespace transfer{

class TransferSocket {
public:
    typedef enum {
	STATUS_STARTED  = 0,
	STATUS_SRM_GET  = 1,
	STATUS_SRM_PUT  = 2,
	STATUS_TRANSFER = 3,
	STATUS_SRM_GETDONE = 4,
	STATUS_SRM_PUTDONE = 5,
	STATUS_DONE     = 6,
	STATUS_FAILED   = 7,
	STATUS_SRM_SETRUNNING = 8
    } Status;

    /**
     * Set up the socket parameters and initialize the TransferFile object
     */
    TransferSocket(const std::string &ID);

    /**
     * Destructor
     */
    ~TransferSocket();

    /**
     * Open a client connection
     */
    void openClient();

    /**
     * Close a client connection
     */
    void closeClient();

    /**
     * Send a message
     */
    long sendMessage(const char *message);

    /**
     * Retrieve a message
     */
    const std::string & getMessage();

    /**
     * Static method returning the string representation of the status number
     */
    static const char * statusStr(int s);

    /**
     * Return the file object
     */
    const TransferFiles & getFiles() {return m_files;}

private:
    TransferFiles m_files;
    struct sockaddr_un  m_sockaddr;
    std::string         m_recv;
    int                 m_sock;
    static const char * s_statuses[];
};

} // namespace transfer
} // namespace glite

#endif //GLITE_DATA_TRANSFER_SOCKET_HXX_
